Interfaces and Signatures
=========================

TODO

### Reader Signature

### Contextual Interface

### Mappable Interface

### Hierarchical Interface

### Inherits Interface

### Importer Interface

### HasMetadata Interface

### Renderable Interface

### Normalizable Interface
